@@ -19,6 +19,7 @@ from typing import (
     List,
 )
 from aiofiles.threadpool.binary import AsyncBufferedIOBase
+from aiohttp.streams import AsyncStreamIterator
 
 import aiohttp
 import aiofiles
@@ -77,6 +78,7 @@ class Client(object):
 
     # HTTP headers for different actions
     DEFAULT_HTTP_HEADER = {
+        "upload": ["Accept: */*", "Content-Type: application/x-www-form-urlencoded"],
         "list": ["Accept: */*", "Depth: 1"],
         "free": ["Accept: */*", "Depth: 0", "Content-Type: text/xml"],
         "copy": ["Accept: */*"],
@@ -144,16 +146,13 @@ class Client(object):
             else None
         )
         self._insecure = insecure
-        self.session = (
-            kwargs.get("session", None) or
-            aiohttp.ClientSession(
+        self.session = kwargs.get("session", None) or aiohttp.ClientSession(
             loop=loop,
             timeout=aiohttp.ClientTimeout(total=timeout)
             if timeout
             else DEFAULT_TIMEOUT,
             auth=aiohttp.BasicAuth(login, password) if (login and password) else None,
             connector=kwargs.get("connector", None),
-            )
         )
 
     def _get_headers(
@@ -531,7 +530,7 @@ class Client(object):
 
         headers = {"Destination": self._get_url(urn_to.quote())}
         if await self.is_directory(urn_from.path()):
-            headers["Depth"] = depth
+            headers["Depth"] = str(depth)
 
         await self._execute_request(
             action="copy", path=urn_from.quote(), headers_ext=headers
@@ -539,7 +538,7 @@ class Client(object):
 
     async def download_iter(
         self, path: Union[str, "os.PathLike[str]"]
-    ) -> Generator[bytes, None, None]:
+    ) -> AsyncStreamIterator[bytes]:
         """
         Downloads file from server and return content in generator.
         More information you can find by link http://webdav.org/specs/rfc4918.html#rfc.section.9.4
@@ -630,7 +629,7 @@ class Client(object):
             raise RemoteResourceNotFound(urn.path())
 
         response = await self._execute_request("download", urn.quote())
-        total = int(response.headers["content-length"])
+        total = response.content_length
         current = 0
 
         if callable(progress):
@@ -853,7 +852,7 @@ class Client(object):
                 In order do you select use a async generator `progress` callback cannot be called.
 
             overwrite (``bool``)
-                If true the will be overwriten by the new data if the a file with the same path exists. 
+                If true the will be overwriten by the new data if the a file with the same path exists.
                 (Default to true)
 
             progress (``callable``, *optional*):
@@ -953,7 +952,7 @@ class Client(object):
                 The path to local file for uploading.
 
             overwrite (``bool``)
-                If true the will be overwriten by the new data if the a file with the same path exists. 
+                If true the will be overwriten by the new data if the a file with the same path exists.
                 (Default to true)
 
             progress (``callable``, *optional*):
@@ -1024,7 +1023,7 @@ class Client(object):
                 The path to local directory for uploading.
 
             overwrite (``bool``)
-                If true the will be overwriten by the new data if the directory with the same path exists. 
+                If true the will be overwriten by the new data if the directory with the same path exists.
                 (Default to true)
 
             progress (``callable``, *optional*):
@@ -1059,7 +1058,7 @@ class Client(object):
         if not os.path.exists(local_path):
             raise LocalResourceNotFound(local_path)
 
-        if (await self.exists(urn.path())):
+        if await self.exists(urn.path()):
             if overwrite:
                 await self.unlink(urn.path())
             else:
@@ -1183,10 +1182,10 @@ class Client(object):
         """
 
         urn = Urn(path)
-        if not (await self.check(urn.path())):
+        if not (await self.exists(urn.path())):
             raise RemoteResourceNotFound(urn.path())
 
-        data = WebDavXmlUtils.create_set_property_batch_request_content(option)
+        data = WebDavXmlUtils.create_set_property_batch_request_content([option])
         await self._execute_request(action="set_property", path=urn.quote(), data=data)
 
     async def close(self):
